Tadpole
-------

flask starter, provide simple flask app start and management,
integration with some useful flask extensions and frequently
used python packages.


Installation
------------

Tadpole requires **Python 2.x >= 2.6**.

Install from PyPI::

    $ pip install tadpole


Usage
-----

Basic usage::

    $ tadpole init -n APP_NAME -v APP_VERSION

Where ``APP_NAME`` is your own project name and ``APP_VERSION`` is your project init version
